From: Dhruv Chawla <[email protected]>
Signed-off-by: Dhruv Chawla <[email protected]>
gcc/objc/ChangeLog:
07:55:42 [5/1594]
* objc-act.cc (objc_compare_types): Fix typos.
(objc_decl_method_attributes): Likewise.
(build_fast_enumeration_state_template): Likewise.
(objc_finish_foreach_loop): Likewise.
* objc-act.h (objc_common_register_features): Likewise.
* objc-runtime-hooks.h (struct objc_runtime_hooks): Likewise.
gcc/ChangeLog:
* omp-expand.cc (expand_oacc_collapse_vars): Likewise.
(expand_omp_for_init_vars): Likewise.
(expand_omp_for): Likewise.
(expand_omp_atomic_fetch_op): Likewise.
(build_omp_regions_1): Likewise.
* omp-general.cc (omp_is_allocatable_or_ptr): Likewise.
* omp-low.cc (lower_rec_input_clauses): Likewise.
(lower_omp): Likewise.
* omp-offload.cc (oacc_validate_dims): Likewise.
(oacc_loop_process): Likewise.
(oacc_loop_fixed_partitions): Likewise.
(oacc_loop_auto_partitions): Likewise.
(execute_oacc_device_lower): Likewise.
* omp-simd-clone.cc (simd_clone_clauses_extract): Likewise.
(ipa_simd_modify_stmt_ops): Likewise.
* optabs-query.cc (lshift_cheap_p): Likewise.
* optabs-query.h (trapv_binoptab_p): Likewise.
(get_vec_cmp_icode): Likewise.
* optabs.cc (expand_binop): Likewise.
(expand_vec_perm_var): Likewise.
(expand_compare_and_swap_loop): Likewise.
(expand_atomic_load): Likewise.
(maybe_optimize_fetch_op): Likewise.
(can_reuse_operands_p): Likewise.
* opts-global.cc (init_options_once): Likewise.
* opts.h (struct cl_option): Likewise.
* pair-fusion.cc (pair_fusion_bb_info::try_fuse_pair): Likewise.
* pair-fusion.h (enum class): Likewise.
* passes.cc (account_profile_1): Likewise.
* path-coverage.cc (instrument_prime_paths): Likewise.
* plugin.cc (get_event_last): Likewise.
* pointer-query.cc (handle_min_max_size): Likewise.
(handle_array_ref): Likewise.
(handle_ssa_name): Likewise.
* poly-int.h (struct if_lossless): Likewise.
(POLY_POLY_COEFF): Likewise.
* postreload-gcse.cc (gcse_after_reload_main): Likewise.
* predict.cc (expr_expected_value_1): Likewise.
(is_exit_with_zero_arg): Likewise.
(predict_paths_for_bb): Likewise.
(estimate_bb_frequencies): Likewise.
(rebuild_frequencies): Likewise.
(make_pass_rebuild_frequencies): Likewise.
* pretty-print-format-impl.h: Likewise.
* pretty-print.h: Likewise.
* prime-paths.cc (struct xpair): Likewise.
(edge_matrix): Likewise.
(test_build_ccfg): Likewise.
* print-rtl.cc (rtx_writer::print_rtx_operand_code_r): Likewise.
* profile-count.h (class profile_probability): Likewise.
* pta-andersen.cc (merge_node_constraints): Likewise.
(add_graph_edge): Likewise.
* range-op.cc (bool): Likewise.
(operator_cast::op1_range): Likewise.
(operator_bitwise_and::wi_fold): Likewise.
(operator_bitwise_and::op1_range): Likewise.
* range-op.h: Likewise.
* read-md.h (class md_reader): Likewise.
* read-rtl-function.cc (lookup_reg_by_dump_name): Likewise.
* real.cc: Likewise.
* recog.h: Likewise.
* ree.cc (find_and_remove_re): Likewise.
* reg-notes.def (REG_CFA_NOTE): Likewise.
* reginfo.cc (reg_allocno_class): Likewise.
* reload1.cc (will_delete_init_insn_p): Likewise.
(emit_reload_insns): Likewise.
* resource.cc (mark_referenced_resources): Likewise.
(mark_target_live_regs): Likewise.
* rtl.def (DEFINE_SPECIAL_PREDICATE): Likewise.
(COND): Likewise.
(DEFINE_SUBST): Likewise.
* rtl.h (const_vec_series_p_1): Likewise.
(const_vec_series_p): Likewise.
---
gcc/objc/objc-act.cc | 8 ++++----
gcc/objc/objc-act.h | 2 +-
gcc/objc/objc-runtime-hooks.h | 2 +-
gcc/omp-expand.cc | 10 +++++-----
gcc/omp-general.cc | 2 +-
gcc/omp-low.cc | 4 ++--
gcc/omp-offload.cc | 14 +++++++-------
gcc/omp-simd-clone.cc | 4 ++--
gcc/optabs-query.cc | 2 +-
gcc/optabs-query.h | 4 ++--
gcc/optabs.cc | 12 ++++++------
gcc/opts-global.cc | 2 +-
gcc/opts.h | 2 +-
gcc/pair-fusion.cc | 4 ++--
gcc/pair-fusion.h | 4 ++--
gcc/passes.cc | 4 ++--
gcc/path-coverage.cc | 2 +-
gcc/plugin.cc | 2 +-
gcc/pointer-query.cc | 6 +++---
gcc/poly-int.h | 4 ++--
gcc/postreload-gcse.cc | 2 +-
gcc/predict.cc | 26 +++++++++++++-------------
gcc/pretty-print-format-impl.h | 2 +-
gcc/pretty-print.h | 2 +-
gcc/prime-paths.cc | 12 ++++++------
gcc/print-rtl.cc | 2 +-
gcc/profile-count.h | 4 ++--
gcc/pta-andersen.cc | 4 ++--
gcc/range-op.cc | 10 +++++-----
gcc/range-op.h | 2 +-
gcc/read-md.h | 4 ++--
gcc/read-rtl-function.cc | 2 +-
gcc/real.cc | 2 +-
gcc/recog.h | 2 +-
gcc/ree.cc | 2 +-
gcc/reg-notes.def | 2 +-
gcc/reginfo.cc | 2 +-
gcc/reload1.cc | 4 ++--
gcc/resource.cc | 4 ++--
gcc/rtl.def | 6 +++---
gcc/rtl.h | 4 ++--
41 files changed, 97 insertions(+), 97 deletions(-)
diff --git a/gcc/objc/objc-act.cc b/gcc/objc/objc-act.cc
index 0a3c44499a8..c8767004682 100644
--- a/gcc/objc/objc-act.cc
+++ b/gcc/objc/objc-act.cc
@@ -2572,7 +2572,7 @@ objc_compare_types (tree ltyp, tree rtyp, int argno, tree
callee)
ltyp = function_args_iter_cond (&liter);
rtyp = function_args_iter_cond (&riter);
- /* If we've exhaused both lists simulateously, we're done. */
+ /* If we've exhausted both lists simulateously, we're done. */
if (ltyp == NULL_TREE && rtyp == NULL_TREE)
break;
@@ -5096,7 +5096,7 @@ objc_decl_method_attributes (tree *node, tree attributes,
int flags)
{
/* We need to fixup all the argument indexes by adding 2
for the two hidden arguments of an Objective-C method
- invocation, similat to what we do above for the
+ invocation, similar to what we do above for the
"format" attribute. */
/* FIXME: This works great in terms of implementing the
functionality, but the warnings that are produced by
@@ -9843,7 +9843,7 @@ build_fast_enumeration_state_template (void)
next_object:
if (__objc_foreach_mutation_pointer !=
*__objc_foreach_enum_state.mutationsPtr) objc_enumeration_mutation (<collection
expression>);
<object expression> = enumState.itemsPtr[__objc_foreach_index];
- <statements> [PS: inside <statments>, 'break' jumps to break_label
and 'continue' jumps to continue_label]
+ <statements> [PS: inside <statements>, 'break' jumps to break_label
and 'continue' jumps to continue_label]
continue_label:
__objc_foreach_index++;
@@ -10181,7 +10181,7 @@ objc_finish_foreach_loop (location_t location, tree
object_expression, tree coll
SET_EXPR_LOCATION (t, location);
append_to_statement_list (t, &BIND_EXPR_BODY (next_batch_bind));
- /* <statements> [PS: in <statments>, 'break' jumps to break_label and
'continue' jumps to continue_label] */
+ /* <statements> [PS: in <statements>, 'break' jumps to break_label and
'continue' jumps to continue_label] */
append_to_statement_list (for_body, &BIND_EXPR_BODY (next_batch_bind));
/* continue_label: */
diff --git a/gcc/objc/objc-act.h b/gcc/objc/objc-act.h
index bd61ce35632..141364d3a83 100644
--- a/gcc/objc/objc-act.h
+++ b/gcc/objc/objc-act.h
@@ -67,7 +67,7 @@ void objc_common_register_features ();
(INSTANCE_METHOD_OR_CLASS_METHOD_DECL_CHECK (DECL)->decl_common.size_unit)
-/* PROPERTY_DECL. A PROPERTY_DECL repesents a @property declaration
+/* PROPERTY_DECL. A PROPERTY_DECL represents a @property declaration
(when attached to the list of properties of an interface) or a
@synthesize or @dynamic declaration (when attached to the list of
properties of an implementation). */
diff --git a/gcc/objc/objc-runtime-hooks.h b/gcc/objc/objc-runtime-hooks.h
index 8612ea07d79..1f490495aad 100644
--- a/gcc/objc/objc-runtime-hooks.h
+++ b/gcc/objc/objc-runtime-hooks.h
@@ -82,7 +82,7 @@ struct objc_runtime_hooks
/* Check for or otherwise handle a request to check that the constant
string class reference is set-up & OK. */
bool (*setup_const_string_class_decl) (void);
- /* Return the tree reprenting a const string constructor for the arg.
+ /* Return the tree representing a const string constructor for the arg.
Most of the data are in global trees. */
tree (*build_const_string_constructor) (location_t, tree, int);
diff --git a/gcc/omp-expand.cc b/gcc/omp-expand.cc
index f7db4542b7d..4d5e81f3fb1 100644
--- a/gcc/omp-expand.cc
+++ b/gcc/omp-expand.cc
@@ -1798,7 +1798,7 @@ expand_oacc_collapse_vars (const struct omp_for_data *fd,
bool inner,
store number of iterations of the loops from fd->first_nonrect
to fd->last_nonrect inclusive, i.e. the above COUNT multiplied
by the counts of rectangular loops not referenced in any non-rectangular
- loops sandwitched in between those. */
+ loops sandwiched in between those. */
/* NOTE: It *could* be better to moosh all of the BBs together,
creating one larger BB with all the computation and the unexpected
@@ -2811,7 +2811,7 @@ expand_omp_for_init_vars (struct omp_for_data *fd,
gimple_stmt_iterator *gsi,
}
/* Fallback implementation. Evaluate the loops in between
(inclusive) fd->first_nonrect and fd->last_nonrect at
- runtime unsing temporaries instead of the original iteration
+ runtime using temporaries instead of the original iteration
variables, in the body just bump the counter and compare
with the desired value. */
gimple_stmt_iterator gsi2 = *gsi;
@@ -8253,7 +8253,7 @@ expand_omp_for (struct omp_region *region, gimple
*inner_stmt)
FALLTHRU_EDGE (region->cont)->flags &= ~EDGE_ABNORMAL;
}
else
- /* If there isn't a continue then this is a degerate case where
+ /* If there isn't a continue then this is a degenerate case where
the introduction of abnormal edges during lowering will prevent
original loops from being detected. Fix that up. */
loops_state_set (LOOPS_NEED_FIXUP);
@@ -9035,7 +9035,7 @@ expand_omp_atomic_fetch_op (basic_block load_bb,
/* We could test all of the various optabs involved, but the fact of the
matter is that (with the exception of i486 vs i586 and xadd) all targets
- that support any atomic operaton optab also implements compare-and-swap.
+ that support any atomic operation optab also implements compare-and-swap.
Let optabs.cc take care of expanding any compare-and-swap loop. */
if (!can_compare_and_swap_p (imode, true) || !can_atomic_load_p (imode))
return false;
@@ -10863,7 +10863,7 @@ build_omp_regions_1 (basic_block bb, struct omp_region
*parent,
region = NULL;
else if (code == GIMPLE_OMP_TASKGROUP)
/* #pragma omp taskgroup isn't a stand-alone directive, but
- gimplifier put the end API call into try finall block
+ gimplifier put the end API call into try finally block
for it, so omp expansion can treat it as such. */
region = NULL;
/* ..., this directive becomes the parent for a new region. */
diff --git a/gcc/omp-general.cc b/gcc/omp-general.cc
index cf8cddc50bc..ffde483c8d2 100644
--- a/gcc/omp-general.cc
+++ b/gcc/omp-general.cc
@@ -68,7 +68,7 @@ omp_is_allocatable_or_ptr (tree decl)
/* Check whether this DECL belongs to a Fortran optional argument.
With 'for_present_check' set to false, decls which are optional parameters
- themselve are returned as tree - or a NULL_TREE otherwise. Those decls are
+ themselves are returned as tree - or a NULL_TREE otherwise. Those decls are
always pointers. With 'for_present_check' set to true, the decl for
checking
whether an argument is present is returned; for arguments with value
attribute this is the hidden argument and of BOOLEAN_TYPE. If the decl is
diff --git a/gcc/omp-low.cc b/gcc/omp-low.cc
index b93012107f1..b18ce8fa1d6 100644
--- a/gcc/omp-low.cc
+++ b/gcc/omp-low.cc
@@ -5819,7 +5819,7 @@ lower_rec_input_clauses (tree clauses, gimple_seq *ilist,
gimple_seq *dlist,
{
/* For reduction in SIMD loop, defer adding the
initialization of the reference, because if we decide
- to use SIMD array for it, the initilization could cause
+ to use SIMD array for it, the initialization could cause
expansion ICE. Ditto for other privatization clauses. */
if (is_simd)
x = NULL_TREE;
@@ -15287,7 +15287,7 @@ lower_omp (gimple_seq *body, omp_context *ctx)
gimple_stmt_iterator gsi;
for (gsi = gsi_start (*body); !gsi_end_p (gsi); gsi_next (&gsi))
lower_omp_1 (&gsi, ctx);
- /* During gimplification, we haven't folded statments inside offloading
+ /* During gimplification, we haven't folded statements inside offloading
or taskreg regions (gimplify.cc:maybe_fold_stmt); do that now. */
if (target_nesting_level || taskreg_nesting_level)
for (gsi = gsi_start (*body); !gsi_end_p (gsi); gsi_next (&gsi))
diff --git a/gcc/omp-simd-clone.cc b/gcc/omp-simd-clone.cc
index 630864d948f..7564846fac4 100644
--- a/gcc/omp-simd-clone.cc
+++ b/gcc/omp-simd-clone.cc
@@ -476,7 +476,7 @@ simd_clone_clauses_extract (struct cgraph_node *node, tree
clauses,
}
/* Given a SIMD clone in NODE, calculate the characteristic data
- type and return the coresponding type. The characteristic data
+ type and return the corresponding type. The characteristic data
type is computed as described in the Intel Vector ABI. */
static tree
@@ -1137,7 +1137,7 @@ ipa_simd_modify_stmt_ops (tree *tp, int *walk_subtrees,
void *data)
offset into the corresponding simd_array.
This function will replace all function argument uses with their
- corresponding simd array elements, and ajust the return values
+ corresponding simd array elements, and adjust the return values
accordingly. */
static void
diff --git a/gcc/optabs-query.cc b/gcc/optabs-query.cc
index 40eaa3b8570..e596d8db881 100644
--- a/gcc/optabs-query.cc
+++ b/gcc/optabs-query.cc
@@ -656,7 +656,7 @@ lshift_cheap_p (bool speed_p)
static bool init[2] = { false, false };
static bool cheap[2] = { true, true };
- /* If the targer has no lshift in word_mode, the operation will most
+ /* If the target has no lshift in word_mode, the operation will most
probably not be cheap. ??? Does GCC even work for such targets? */
if (optab_handler (ashl_optab, word_mode) == CODE_FOR_nothing)
return false;
diff --git a/gcc/optabs-query.h b/gcc/optabs-query.h
index 395330c80de..faa688a0609 100644
--- a/gcc/optabs-query.h
+++ b/gcc/optabs-query.h
@@ -90,7 +90,7 @@ trapv_binoptab_p (optab binoptab)
}
/* Return insn code for a comparison operator with VMODE
- resultin MASK_MODE, unsigned if UNS is true. */
+ result in MASK_MODE, unsigned if UNS is true. */
inline enum insn_code
get_vec_cmp_icode (machine_mode vmode, machine_mode mask_mode, bool uns)
@@ -100,7 +100,7 @@ get_vec_cmp_icode (machine_mode vmode, machine_mode
mask_mode, bool uns)
}
/* Return insn code for a comparison operator with VMODE
- resultin MASK_MODE (only for EQ/NE). */
+ result in MASK_MODE (only for EQ/NE). */
inline enum insn_code
get_vec_cmp_eq_icode (machine_mode vmode, machine_mode mask_mode)
diff --git a/gcc/optabs.cc b/gcc/optabs.cc
index 87c4ea682fc..9adbe77ab33 100644
--- a/gcc/optabs.cc
+++ b/gcc/optabs.cc
@@ -2178,7 +2178,7 @@ expand_binop (machine_mode mode, optab binoptab, rtx op0,
rtx op1,
}
}
- /* Attempt to synthetize double word modulo by constant divisor. */
+ /* Attempt to synthesize double word modulo by constant divisor. */
if ((binoptab == umod_optab
|| binoptab == smod_optab
|| binoptab == udiv_optab
@@ -7007,7 +7007,7 @@ expand_vec_perm_var (machine_mode mode, rtx v0, rtx v1,
rtx sel, rtx target)
gcc_assert (sel != NULL);
/* Add the byte offset to each byte element. */
- /* Note that the definition of the indicies here is memory ordering,
+ /* Note that the definition of the indices here is memory ordering,
so there should be no difference between big and little endian. */
rtx_vector_builder byte_indices (qimode, u, 1);
for (i = 0; i < u; ++i)
@@ -7234,7 +7234,7 @@ expand_compare_and_swap_loop (rtx mem, rtx old_reg, rtx
new_reg, rtx seq)
}
-/* This function tries to emit an atomic_exchange intruction. VAL is written
+/* This function tries to emit an atomic_exchange instruction. VAL is written
to *MEM using memory model MODEL. The previous contents of *MEM are
returned,
using TARGET if possible. */
@@ -7773,7 +7773,7 @@ expand_atomic_load (rtx target, rtx mem, enum memmodel
model)
then we assume that a load will not be atomic. We could try to
emulate a load with a compare-and-swap operation, but the store that
doing this could result in would be incorrect if this is a volatile
- atomic load or targetting read-only-mapped memory. */
+ atomic load or targeting read-only-mapped memory. */
if (maybe_gt (GET_MODE_PRECISION (mode), BITS_PER_WORD))
/* If there is no atomic load, leave the library call. */
return NULL_RTX;
@@ -8001,7 +8001,7 @@ maybe_optimize_fetch_op (rtx target, rtx mem, rtx val,
enum rtx_code code,
return NULL_RTX;
}
-/* Try to emit an instruction for a specific operation varaition.
+/* Try to emit an instruction for a specific operation variation.
OPTAB contains the OP functions.
TARGET is an optional place to return the result. const0_rtx means unused.
MEM is the memory location to operate on.
@@ -8509,7 +8509,7 @@ can_reuse_operands_p (enum insn_code icode,
{
case EXPAND_OUTPUT:
case EXPAND_UNDEFINED_INPUT:
- /* Outputs and undefined intputs must remain distinct. */
+ /* Outputs and undefined inputs must remain distinct. */
return false;
case EXPAND_FIXED:
diff --git a/gcc/opts-global.cc b/gcc/opts-global.cc
index 6f111ab69ef..30fad240d83 100644
--- a/gcc/opts-global.cc
+++ b/gcc/opts-global.cc
@@ -263,7 +263,7 @@ init_options_once (void)
/* ??? Ideally, we should do this earlier and the FEs will override
it if desired (none do it so far). However, the way the FEs
construct their pretty-printers means that all previous settings
- are overriden. */
+ are overridden. */
global_dc->set_show_highlight_colors (show_highlight_colors);
diagnostic_color_init (global_dc);
diff --git a/gcc/opts.h b/gcc/opts.h
index 2d28620edab..1934ce4f650 100644
--- a/gcc/opts.h
+++ b/gcc/opts.h
@@ -88,7 +88,7 @@ struct cl_option
/* Option length, not including initial '-'. */
unsigned char opt_len;
/* Next option in a sequence marked with Negative, or -1 if none.
- For a single option with both a negative and a positve form
+ For a single option with both a negative and a positive form
(such as -Wall and -Wno-all), NEG_IDX is equal to the option's
own index (i.e., cl_options[IDX].neg_idx == IDX holds). */
int neg_index;
diff --git a/gcc/pair-fusion.cc b/gcc/pair-fusion.cc
index 7aaf4fd6372..915497c97d3 100644
--- a/gcc/pair-fusion.cc
+++ b/gcc/pair-fusion.cc
@@ -930,7 +930,7 @@ private:
// are deleting both original insns and inserting a new insn for the stp.
insn_info *m_repurpose;
- // Destionation of the stp, it will be placed immediately after m_dest.
+ // Destination of the stp, it will be placed immediately after m_dest.
insn_info *m_dest;
// Current nondebug use that needs updating due to stp insertion.
@@ -2522,7 +2522,7 @@ pair_fusion_bb_info::try_fuse_pair (bool load_p, unsigned
access_size,
{
if (dump_file)
fprintf (dump_file,
- "punting on load pair due to reg conflcits (%d,%d)\n",
+ "punting on load pair due to reg conflicts (%d,%d)\n",
insns[0]->uid (), insns[1]->uid ());
return false;
}
diff --git a/gcc/pair-fusion.h b/gcc/pair-fusion.h
index 5bcdc6f1b8f..44e19bc80fd 100644
--- a/gcc/pair-fusion.h
+++ b/gcc/pair-fusion.h
@@ -1,7 +1,7 @@
// Pass to fuse adjacent loads/stores into paired memory accesses.
//
// This file contains the definition of the virtual base class which is
-// overriden by targets that make use of the pass.
+// overridden by targets that make use of the pass.
//
// Copyright (C) 2023-2026 Free Software Foundation, Inc.
//
@@ -85,7 +85,7 @@ enum class writeback_type {
ALL
};
-// This class can be overriden by targets to give a pass that fuses
+// This class can be overridden by targets to give a pass that fuses
// adjacent loads and stores into load/store pair instructions.
//
// The target can override the various virtual functions to customize
diff --git a/gcc/passes.cc b/gcc/passes.cc
index 9ec37eeb2a9..8b69ea5e69d 100644
--- a/gcc/passes.cc
+++ b/gcc/passes.cc
@@ -81,7 +81,7 @@ opt_pass *current_pass;
need to implement cloning, but passes that support multiple instances
*must* provide their own implementation of the clone method.
- Handle this by providing a default implemenation, but make it a fatal
+ Handle this by providing a default implementation, but make it a fatal
error to call it. */
opt_pass *
@@ -1914,7 +1914,7 @@ account_profile_1 (function *fn, void *data)
pop_cfun ();
}
-/* Account profile chnages to all passes in list starting in SUB. */
+/* Account profile changes to all passes in list starting in SUB. */
static void
account_profile_in_list (opt_pass *sub)
diff --git a/gcc/path-coverage.cc b/gcc/path-coverage.cc
index 68a30d5a8ee..b9c25e3b3d9 100644
--- a/gcc/path-coverage.cc
+++ b/gcc/path-coverage.cc
@@ -635,7 +635,7 @@ instrument_prime_paths (struct function *fn)
else if (all_bits_set_p (*bitmask, bucketsize) && phi)
{
/* This reduces to a no-op (x & ~0). Reusing the SSA and not
- emitting an unecessary AND is a big improvement for large
+ emitting an unnecessary AND is a big improvement for large
programs. */
tree *prev = SSAex.get ({e->src, bucket});
if (prev)
diff --git a/gcc/plugin.cc b/gcc/plugin.cc
index 436be5e0147..c3f01ec4df5 100644
--- a/gcc/plugin.cc
+++ b/gcc/plugin.cc
@@ -1037,7 +1037,7 @@ get_event_last (void)
/* Retrieve the default plugin directory. The gcc driver should have passed
- it as -iplugindir <dir> to the cc1 program, and it is queriable through the
+ it as -iplugindir <dir> to the cc1 program, and it is queryable through the
-print-file-name=plugin option to gcc. */
const char*
default_plugin_dir_name (void)
diff --git a/gcc/pointer-query.cc b/gcc/pointer-query.cc
index 61b0032b2fb..b5ab5cbd1ab 100644
--- a/gcc/pointer-query.cc
+++ b/gcc/pointer-query.cc
@@ -1696,7 +1696,7 @@ handle_min_max_size (tree ptr, int ostype, access_ref
*pref,
{
/* If the object referenced by both arguments has been determined
set *PREF to the one with more or less space remainng, whichever
- is appopriate for CODE.
+ is appropriate for CODE.
TODO: Indicate when the objects are distinct so it can be
diagnosed. */
i0 = code == MAX_EXPR;
@@ -1794,7 +1794,7 @@ handle_array_ref (tree aref, gimple *stmt, bool addr, int
ostype,
tree arefop = TREE_OPERAND (aref, 0);
tree reftype = TREE_TYPE (arefop);
if (!addr && TREE_CODE (TREE_TYPE (reftype)) == POINTER_TYPE)
- /* Avoid arrays of pointers. FIXME: Hande pointers to arrays
+ /* Avoid arrays of pointers. FIXME: Handle pointers to arrays
of known bound. */
return false;
@@ -2027,7 +2027,7 @@ handle_ssa_name (tree ptr, bool addr, int ostype,
qry->max_depth = qry->depth;
if (const access_ref *cache_ref = qry->get_ref (ptr, ostype))
{
- /* Add the number of DEREFerences accummulated so far. */
+ /* Add the number of DEREFerences accumulated so far. */
const int deref = pref->deref;
*pref = *cache_ref;
pref->deref += deref;
diff --git a/gcc/postreload-gcse.cc b/gcc/postreload-gcse.cc
index 4656b881865..2203c60ae91 100644
--- a/gcc/postreload-gcse.cc
+++ b/gcc/postreload-gcse.cc
@@ -1372,7 +1372,7 @@ gcse_after_reload_main (rtx f ATTRIBUTE_UNUSED)
if (!expr_table->is_empty ())
{
- /* Knowing which MEMs are transparent through a block can signifiantly
+ /* Knowing which MEMs are transparent through a block can significantly
increase the number of redundant loads found. So compute transparency
information for each memory expression in the hash table. */
df_analyze ();
diff --git a/gcc/pretty-print-format-impl.h b/gcc/pretty-print-format-impl.h
index e1311ef9946..025974562be 100644
--- a/gcc/pretty-print-format-impl.h
+++ b/gcc/pretty-print-format-impl.h
@@ -439,7 +439,7 @@ private:
BEGIN_URL("http://example.com"), TEXT("-foption"), END_URL, END_QUOTE]
(5) emits all tokens in sequence with appropriate line-wrapping. This
- can be overridded via the pretty_printer's token_printer, allowing for
+ can be overridden via the pretty_printer's token_printer, allowing for
output formats to e.g. override how URLs are handled, or to handle
custom_data that wasn't lowered in (2) above, e.g. for handling JSON
output of optimization records. */
diff --git a/gcc/pretty-print.h b/gcc/pretty-print.h
index fc4813420aa..0e4ecb74127 100644
--- a/gcc/pretty-print.h
+++ b/gcc/pretty-print.h
@@ -360,7 +360,7 @@ private:
/* If non-NULL, this is called by pp_format once after all format codes
have been processed, to allow for client-specific postprocessing.
This is used by the C++ frontend for handling the %H and %I
- format codes (which interract with each other). */
+ format codes (which interact with each other). */
std::unique_ptr<format_postprocessor> m_format_postprocessor;
/* This is used by pp_output_formatted_text after it has converted all
diff --git a/gcc/prime-paths.cc b/gcc/prime-paths.cc
index c3795fcda74..e1b02c2eb03 100644
--- a/gcc/prime-paths.cc
+++ b/gcc/prime-paths.cc
@@ -126,13 +126,13 @@ struct xpair
The union of near/far is essentially a short-vector optimization, switching
to a heap-allocated vector when necessary. This happens relatively rarely
- (usually maxes out at 1-2%), and the vertices that have more than 2
sucessors
+ (usually maxes out at 1-2%), and the vertices that have more than 2
successors
also tend to have more than 4. The root vertex tends to use the dynamic
vector because the subpaths are recorded as the successors of the root.
Conceptually, this is a small map from vertex-id -> index and the API is
modelled as such. The insert and search functions are unrolled by hand when
- using the small vector. This has a noticable performance impact on insert
in
+ using the small vector. This has a noticeable performance impact on insert
in
particular, and is not too complex since we know we are limited to 2
elements.
@@ -150,7 +150,7 @@ struct xpair
in [2 4 6] is cleared when the suffixes of [9 7 2 4 6] are inserted.
The node will be inserted into a vec, and should be trivial. Instances
- should be value-initialized to zero-intialized state. */
+ should be value-initialized to zero-initialized state. */
struct trie_node
{
unsigned length () const
@@ -1333,10 +1333,10 @@ edge_matrix (const struct graph *cfg)
The algorithm is based on Fazli & Afsharchi's "A Time and Space-Efficient
Compositional Method for Prime and Test Paths Generation" (2019), combined
- with a suffix trie for removing duplicate or redundant paths. An auxillary
+ with a suffix trie for removing duplicate or redundant paths. An auxiliary
graph of the strongly connected components (SCCs) is built. Then, the prime
paths of the SCCs composes the prime paths of each SCC with the prime paths
- of this auxillary graph. This can drastically cut the number of redundant
+ of this auxiliary graph. This can drastically cut the number of redundant
paths generated compared to a naive algorithm.
This does not work for all graphs. Some structures, e.g. when most of the
@@ -1652,7 +1652,7 @@ test_build_ccfg ()
/* This test checks some basic assumptions on finding the strongly connected
components and disconnecting the graph by removing all edges between SCCs.
- Creating a single auxillary graph simplifies the bookkeeping. */
+ Creating a single auxiliary graph simplifies the bookkeeping. */
static void
test_split_components ()
{
diff --git a/gcc/print-rtl.cc b/gcc/print-rtl.cc
index 57ef67b08f8..0c18a994209 100644
--- a/gcc/print-rtl.cc
+++ b/gcc/print-rtl.cc
@@ -579,7 +579,7 @@ rtx_writer::print_rtx_operand_code_r (const_rtx in_rtx)
else if (m_compact)
{
/* In compact mode, print pseudos with '< and '>' wrapping the regno,
- offseting it by (LAST_VIRTUAL_REGISTER + 1), so that the
+ offsetting it by (LAST_VIRTUAL_REGISTER + 1), so that the
first non-virtual pseudo is dumped as "<0>". */
gcc_assert (regno > LAST_VIRTUAL_REGISTER);
fprintf (m_outfile, " <%d>", regno - (LAST_VIRTUAL_REGISTER + 1));
diff --git a/gcc/profile-count.h b/gcc/profile-count.h
index d02ab8bded9..b424ecba3ea 100644
--- a/gcc/profile-count.h
+++ b/gcc/profile-count.h
@@ -154,7 +154,7 @@ class GTY((user)) profile_probability
static const uint32_t uninitialized_probability
= ((uint32_t) 1 << (n_bits - 1)) - 1;
/* For probibilityes quality is either UNINITIALIZED (0)
- or greated then GUESSED. To save bits we store it in
+ or greater then GUESSED. To save bits we store it in
adjusted form which skips the invalid values. */
static const int min_quality = GUESSED;
@@ -1203,7 +1203,7 @@ public:
{
/* This is common case of AFDO scaling when we upgrade
GLOBAL0_AFDO function to AFDO. Be sure that result
- is AFDO and not GUESSED (which is unnecesarily low). */
+ is AFDO and not GUESSED (which is unnecessarily low). */
if (num.m_quality == AFDO
&& (ret.m_quality != GUESSED
&& ret.m_quality != GUESSED_LOCAL))
diff --git a/gcc/pta-andersen.cc b/gcc/pta-andersen.cc
index f97d36e73b5..bba34b3c9a0 100644
--- a/gcc/pta-andersen.cc
+++ b/gcc/pta-andersen.cc
@@ -527,7 +527,7 @@ merge_node_constraints (constraint_graph_t graph, unsigned
int to,
FOR_EACH_VEC_ELT (graph->complex[from], i, c)
{
/* In complex constraints for node FROM, we may have either
- a = *FROM, and *FROM = a, or an offseted constraint which are
+ a = *FROM, and *FROM = a, or an offsetted constraint which are
always added to the rhs node's constraints. */
if (c->rhs.type == DEREF)
@@ -641,7 +641,7 @@ add_graph_edge (constraint_graph_t graph, unsigned int to,
adding the direct edge FROM -> TO when we have FROM -> ESCAPED
and TO contains ESCAPED.
??? Note this is only a heuristic, it does not prevent the
- situation from occuring. The heuristic helps PR38474 and
+ situation from occurring. The heuristic helps PR38474 and
PR99912 significantly. */
if (to < FIRST_REF_NODE
&& bitmap_bit_p (graph->succs[from], find (escaped_id))
diff --git a/gcc/range-op.cc b/gcc/range-op.cc
index 40c62c3a2d6..689665295fa 100644
--- a/gcc/range-op.cc
+++ b/gcc/range-op.cc
@@ -143,7 +143,7 @@ range_op_handler::operator bool () const
return m_operator != &default_operator;
}
-// Return a pointer to the range operator assocaited with this handler.
+// Return a pointer to the range operator associated with this handler.
// If it is a default operator, return nullptr.
// This is the equivalent of indexing the range table.
@@ -3242,7 +3242,7 @@ operator_cast::op1_range (irange &r, tree type,
wide_int value = wide_int::from (bm.value (), TYPE_PRECISION (type),
UNSIGNED);
- // Set then additonal unknown bits in mask.
+ // Set then additional unknown bits in mask.
wide_int lim = wi::mask (TYPE_PRECISION (lhs_type), true,
TYPE_PRECISION (type));
mask = mask | lim;
@@ -3623,8 +3623,8 @@ operator_bitwise_and::wi_fold (irange &r, tree type,
const wide_int &rh_ub) const
{
// The AND algorithm does not handle complex signed operations well.
- // If a signed range crosses the boundry between signed and unsigned
- // proces sit as 2 ranges and union the results.
+ // If a signed range crosses the boundary between signed and unsigned
+ // process it as 2 ranges and union the results.
if (TYPE_SIGN (type) == SIGNED
&& wi::neg_p (lh_lb, SIGNED) != wi::neg_p (lh_ub, SIGNED))
{
@@ -3869,7 +3869,7 @@ operator_bitwise_and::op1_range (irange &r, tree type,
op1_mask |= lhs_bm.mask ();
// The resulting zeros correspond to known bits in the LHS mask, and
// the LHS value should tell us what they are. Mask off any
- // extraneous values thats are not convered by the mask.
+ // extraneous values that are not covered by the mask.
wide_int op1_value = lhs_bm.value () & ~op1_mask;
irange_bitmask op1_bm (op1_value, op1_mask);
// Intersect this mask with anything already known about the value.
diff --git a/gcc/range-op.h b/gcc/range-op.h
index 36e99a6f912..1e18fa5f4ed 100644
--- a/gcc/range-op.h
+++ b/gcc/range-op.h
@@ -238,7 +238,7 @@ public:
virtual bool overflow_free_p (const irange &lh, const irange &rh,
relation_trio = TRIO_VARYING) const;
- // Compatability check for operands.
+ // Compatibility check for operands.
virtual bool operand_check_p (tree, tree, tree) const;
protected:
diff --git a/gcc/read-md.h b/gcc/read-md.h
index 83d5c6867ca..f5fa81ddf16 100644
--- a/gcc/read-md.h
+++ b/gcc/read-md.h
@@ -318,7 +318,7 @@ class md_reader
htab_t m_overloads_htab;
};
-/* Global singleton; constrast with rtx_reader_ptr below. */
+/* Global singleton; contrast with rtx_reader_ptr below. */
extern md_reader *md_reader_ptr;
/* An md_reader subclass which skips unknown directives, for
@@ -370,7 +370,7 @@ class rtx_reader : public md_reader
#endif
};
-/* Global singleton; constrast with md_reader_ptr above. */
+/* Global singleton; contrast with md_reader_ptr above. */
extern rtx_reader *rtx_reader_ptr;
extern void (*include_callback) (const char *);
diff --git a/gcc/read-rtl-function.cc b/gcc/read-rtl-function.cc
index 7490a6eb81b..25e27686a42 100644
--- a/gcc/read-rtl-function.cc
+++ b/gcc/read-rtl-function.cc
@@ -356,7 +356,7 @@ lookup_reg_by_dump_name (const char *name)
/* TODO: handle "virtual-reg-%d". */
/* In compact mode, pseudos are printed with '< and '>' wrapping the regno,
- offseting it by (LAST_VIRTUAL_REGISTER + 1), so that the
+ offsetting it by (LAST_VIRTUAL_REGISTER + 1), so that the
first non-virtual pseudo is dumped as "<0>". */
if (name[0] == '<' && name[strlen (name) - 1] == '>')
{
diff --git a/gcc/real.cc b/gcc/real.cc
index e207bae734e..4c017cb878d 100644
--- a/gcc/real.cc
+++ b/gcc/real.cc
@@ -3186,7 +3186,7 @@ const struct real_format motorola_single_format =
- Denormals can be represented, but are treated as +0.0 when
used as an operand and are never generated as a result.
- -0.0 can be represented, but a zero result is always +0.0.
- - the only supported rounding mode is trunction (towards zero). */
+ - the only supported rounding mode is truncation (towards zero). */
const struct real_format spu_single_format =
{
encode_ieee_single,
diff --git a/gcc/recog.h b/gcc/recog.h
index 04cc1f192aa..1f22dbf4d9b 100644
--- a/gcc/recog.h
+++ b/gcc/recog.h
@@ -130,7 +130,7 @@ public:
rtx /*mem*/) { return true; }
/* Note that we've simplified OLD_RTX into NEW_RTX. When substituting,
- this only happens if a substitution occured within OLD_RTX.
+ this only happens if a substitution occurred within OLD_RTX.
Undoing OLD_NUM_CHANGES and up will restore the old form of OLD_RTX.
OLD_RESULT_FLAGS is the value that RESULT_FLAGS had before processing
OLD_RTX. */
diff --git a/gcc/ree.cc b/gcc/ree.cc
index 4be13c35bdc..fb7c33a76d5 100644
--- a/gcc/ree.cc
+++ b/gcc/ree.cc
@@ -1351,7 +1351,7 @@ find_and_remove_re (void)
It may first appear that the arguments for the copy are reversed.
Remember that the memory reference will be changed to refer to the
- destination of the extention. So we're actually emitting a copy
+ destination of the extension. So we're actually emitting a copy
from the new destination to the old destination. */
for (unsigned int i = 0; i < reinsn_copy_list.length (); i += 2)
{
diff --git a/gcc/reg-notes.def b/gcc/reg-notes.def
index b3a598f9540..2f939aee6f3 100644
--- a/gcc/reg-notes.def
+++ b/gcc/reg-notes.def
@@ -164,7 +164,7 @@ REG_CFA_NOTE (CFA_RESTORE)
REG_CFA_NOTE (CFA_NO_RESTORE)
/* Attached to insns that are RTX_FRAME_RELATED_P, marks insn that sets
- vDRAP from DRAP. If vDRAP is a register, vdrap_reg is initalized
+ vDRAP from DRAP. If vDRAP is a register, vdrap_reg is initialized
to the argument, if it is a MEM, it is ignored. */
REG_CFA_NOTE (CFA_SET_VDRAP)
diff --git a/gcc/reginfo.cc b/gcc/reginfo.cc
index 9b515870d55..3dbb4b3f7d0 100644
--- a/gcc/reginfo.cc
+++ b/gcc/reginfo.cc
@@ -856,7 +856,7 @@ reg_allocno_class (int regno)
-/* Allocate space for reg info and initilize it. */
+/* Allocate space for reg info and initialize it. */
static void
allocate_reg_info (void)
{
diff --git a/gcc/reload1.cc b/gcc/reload1.cc
index 8cac4011c46..3cc1bff0928 100644
--- a/gcc/reload1.cc
+++ b/gcc/reload1.cc
@@ -743,7 +743,7 @@ will_delete_init_insn_p (rtx_insn *insn)
so any pseudo reg that is spilled must go to the stack.
Return value is TRUE if reload likely left dead insns in the
- stream and a DCE pass should be run to elimiante them. Else the
+ stream and a DCE pass should be run to eliminate them. Else the
return value is FALSE. */
bool
@@ -8256,7 +8256,7 @@ emit_reload_insns (class insn_chain *chain)
}
/* The following if-statement was #if 0'd in 1.34 (or before...).
- It's reenabled in 1.35 because supposedly nothing else
+ It's re-enabled in 1.35 because supposedly nothing else
deals with this problem. */
/* If a register gets output-reloaded from a non-spill register,
diff --git a/gcc/resource.cc b/gcc/resource.cc
index 6c929e33292..bf8bc713180 100644
--- a/gcc/resource.cc
+++ b/gcc/resource.cc
@@ -369,7 +369,7 @@ mark_referenced_resources (rtx x, struct resources *res,
/* In addition to the usual references, also consider all outputs
as referenced, to compensate for mark_set_resources treating
them as killed. This is similar to ZERO_EXTRACT / STRICT_LOW_PART
- handling, execpt that we got a partial incidence instead of a partial
+ handling, except that we got a partial incidence instead of a partial
width. */
mark_set_resources (x, res, 0,
include_delayed_effects
@@ -800,7 +800,7 @@ mark_target_live_regs (rtx_insn *insns, rtx
target_maybe_return, struct resource
if (CALL_P (real_insn))
{
/* Values in call-clobbered registers survive a COND_EXEC CALL
- if that is not executed; this matters for resoure use because
+ if that is not executed; this matters for resource use because
they may be used by a complementarily (or more strictly)
predicated instruction, or if the CALL is NORETURN. */
if (GET_CODE (PATTERN (real_insn)) != COND_EXEC)
diff --git a/gcc/rtl.def b/gcc/rtl.def
index ad98fd59172..c88b4565b3e 100644
--- a/gcc/rtl.def
+++ b/gcc/rtl.def
@@ -1017,7 +1017,7 @@ DEF_RTL_EXPR(DEFINE_SPECIAL_PREDICATE,
"define_special_predicate", "ses", RTX_EX
2: A docstring for this constraint, in Texinfo syntax; not currently
used, in future will be incorporated into the manual's list of
machine-specific operand constraints.
- 3: A C expression that evalutes to true if "regno" is a valid
+ 3: A C expression that evaluates to true if "regno" is a valid
start register. */
DEF_RTL_EXPR(DEFINE_REGISTER_CONSTRAINT, "define_register_constraint", "sssS",
RTX_EXTRA)
@@ -1337,7 +1337,7 @@ DEF_RTL_EXPR(COND, "cond", "Ee", RTX_EXTRA)
that match the substitution pattern.
Operand:
- 0: The name of the substitition template.
+ 0: The name of the substitution template.
1: Input template to match to see if a substitution is applicable.
2: A C expression giving an additional condition for the generated
new define_expand or define_insn.
@@ -1361,7 +1361,7 @@ DEF_RTL_EXPR(DEFINE_SUBST, "define_subst", "sEsE",
RTX_EXTRA)
name, for the case that the DEFINE_SUBST is not applied (i.e. the
unmodified version of the pattern).
3: String to substitute for the subst-attribute name in the pattern
- name, for the case that the DEFINE_SUBST is applied to the patten.
+ name, for the case that the DEFINE_SUBST is applied to the pattern.
The use of DEFINE_SUBST and DEFINE_SUBST_ATTR is explained in the
GCC internals manual, under "RTL Templates Transformations". */
diff --git a/gcc/omp-offload.cc b/gcc/omp-offload.cc
index 8522644eabc..7cd2a572b7c 100644
--- a/gcc/omp-offload.cc
+++ b/gcc/omp-offload.cc
@@ -806,14 +806,14 @@ oacc_xform_tile (gcall *call)
e_mask = 0;
#endif
if (!e_mask)
- /* Not paritioning. */
+ /* Not partitioning. */
span = integer_one_node;
else if (!integer_zerop (tile_size))
/* User explicitly specified size. */
span = tile_size;
else
{
/* Pick a size based on the paritioning of the element loop and
the number of loop nests. */
tree first_size = NULL_TREE;
tree second_size = NULL_TREE;
@@ -1011,7 +1011,7 @@ oacc_validate_dims (tree fn, tree attrs, int *dims, int
level, unsigned used)
same wording and logic applies to num_workers and
vector_length, however the worker- or vector- single
execution doesn't have the same impact as gang-redundant
- execution. (If the minimum gang-level partioning is not 1,
+ execution. (If the minimum gang-level partitioning is not 1,
the target is probably too confusing.) */
dims[ix] = (used & GOMP_DIM_MASK (ix)
? oacc_default_dims[ix] : oacc_min_dims[ix]);
@@ -1478,7 +1478,7 @@ oacc_loop_process (oacc_loop *loop, int fn_level)
"gang reduction on an orphan loop");
}
-/* Walk the OpenACC loop heirarchy checking and assigning the
+/* Walk the OpenACC loop hierarchy checking and assigning the
programmer-specified partitionings. OUTER_MASK is the partitioning
this loop is contained within. Return mask of partitioning
encountered. If any auto loops are discovered, set GOMP_DIM_MAX
@@ -1628,7 +1628,7 @@ oacc_loop_fixed_partitions (oacc_loop *loop, unsigned
outer_mask)
return mask_all;
}
-/* Walk the OpenACC loop heirarchy to assign auto-partitioned loops.
+/* Walk the OpenACC loop hierarchy to assign auto-partitioned loops.
OUTER_MASK is the partitioning this loop is contained within.
OUTER_ASSIGN is true if an outer loop is being auto-partitioned.
Return the cumulative partitioning used by this loop, siblings and
@@ -1749,7 +1749,7 @@ oacc_loop_auto_partitions (oacc_loop *loop, unsigned
outer_mask,
return inner_mask;
}
-/* Walk the OpenACC loop heirarchy to check and assign partitioning
+/* Walk the OpenACC loop hierarchy to check and assign partitioning
axes. Return mask of partitioning. */
static unsigned
@@ -2379,7 +2379,7 @@ execute_oacc_device_lower ()
2. The address of the variable in the new address space can be taken,
converted to the default (original) address space, and the result of
- that conversion subsituted in place of the original ADDR_EXPR node.
+ that conversion substituted in place of the original ADDR_EXPR node.
Which of these is done depends on the gimple statement being processed.
At present atomic operations and inline asms use (1), and everything else
@@ -806,14 +806,14 @@ oacc_xform_tile (gcall *call)
else
{
- /* Pick a size based on the paritioning of the element loop and
+ /* Pick a size based on the partitioning of the element loop and
the number of loop nests. */
tree first_size = NULL_TREE;
diff --git a/gcc/poly-int.h b/gcc/poly-int.h
index 97946591564..cacd1c21443 100644
--- a/gcc/poly-int.h
+++ b/gcc/poly-int.h
@@ -184,7 +184,7 @@ struct if_lossless<T1, T2, T3, true>
- poly_int_traits<T>::num_coeffs gives the number of coefficients in T
if T is a poly_int and 1 otherwise.
- - poly_int_traits<T>::coeff_type gives the coefficent type of T if T
+ - poly_int_traits<T>::coeff_type gives the coefficient type of T if T
is a poly_int and T itself otherwise
- poly_int_traits<T>::int_type is a shorthand for
@@ -292,7 +292,7 @@ struct poly_result<T1, T2, 2>
second of which has coefficients of type C2. */
#define POLY_POLY_COEFF(C1, C2) typename poly_result<C1, C2>::type
/* Enforce that T2 is non-polynomial and provide the cofficient type of
the result of a binary operation in which the first operand is a
poly_int with coefficients of type C1 and the second operand is
a constant of type T2. */
@@ -292,7 +292,7 @@ struct poly_result<T1, T2, 2>
second of which has coefficients of type C2. */
#define POLY_POLY_COEFF(C1, C2) typename poly_result<C1, C2>::type
-/* Enforce that T2 is non-polynomial and provide the cofficient type of
+/* Enforce that T2 is non-polynomial and provide the coefficient type of
the result of a binary operation in which the first operand is a
poly_int with coefficients of type C1 and the second operand is
diff --git a/gcc/predict.cc b/gcc/predict.cc
index 2859f64964b..53328bb0e0d 100644
--- a/gcc/predict.cc
+++ b/gcc/predict.cc
@@ -2512,8 +2512,8 @@ expr_expected_value_1 (tree type, tree op0, enum
tree_code code,
if (*predictor == predictor2 && p1 == p2)
continue;
/* The general case has no precise solution, since we do not
- know probabilities of incomming edges, yet.
- Still if value is predicted over all incomming edges, we
+ know probabilities of incoming edges, yet.
+ Still if value is predicted over all incoming edges, we
can hope it will be indeed the case. Conservatively
downgrade prediction quality (so first match merging is not
performed) and take least successful prediction. */
@@ -2718,8 +2718,8 @@ expr_expected_value_1 (tree type, tree op0, enum
tree_code code,
example:
op0 * op1
If op0 is 0 with probability p, then we will ignore the
- posibility that op0 != 0 and op1 == 0. It does not seem to be
- worthwhile to downgrade prediciton quality for this. */
+ possibility that op0 != 0 and op1 == 0. It does not seem to be
+ worthwhile to downgrade prediction quality for this. */
return res;
if (!nop0)
nop0 = op0;
@@ -2992,7 +2992,7 @@ is_exit_with_zero_arg (const gimple *stmt)
&& !gimple_call_builtin_p (stmt, BUILT_IN__EXIT2))
return false;
- /* Argument is an interger zero. */
+ /* Argument is an integer zero. */
return integer_zerop (gimple_call_arg (stmt, 0));
}
@@ -3422,7 +3422,7 @@ predict_paths_for_bb (basic_block cur, basic_block bb,
using predictor. Otherwise we need to look for paths
leading to e->src.
- The second may lead to infinite loop in the case we are predicitng
+ The second may lead to infinite loop in the case we are predicting
regions that are only reachable by abnormal edges. We simply
prevent visiting given BB twice. */
if (found)
@@ -4124,7 +4124,7 @@ estimate_bb_frequencies ()
/* Scaling frequencies up to maximal profile count may result in
frequent overflows especially when inlining loops.
- Small scaling results in unnecesary precision loss. Stay in
+ Small scaling results in unnecessary precision loss. Stay in
the half of the (exponential) range. */
freq_max = (sreal (1) << (profile_count::n_bits / 2)) / freq_max;
if (freq_max < 16)
@@ -4481,7 +4481,7 @@ rebuild_frequencies (void)
bb->count);
if (bb->count.nonzero_p () && bb->count.quality () >= AFDO)
feedback_found = true;
/* Uninitialized count may be result of inlining or an omision in an
optimization pass. */
if (!bb->count.initialized_p ())
{
@@ -4501,7 +4501,7 @@ rebuild_frequencies (void)
{
sum += e->count ();
/* Uninitialized probability may be result of inlining or an
- omision in an optimization pass. */
+ omission in an optimization pass. */
if (!e->probability.initialized_p ())
{
if (dump_file)
@@ -4514,7 +4514,7 @@ rebuild_frequencies (void)
{
if (dump_file)
fprintf (dump_file,
- "BB %i has invalid sum of incomming counts\n",
+ "BB %i has invalid sum of incoming counts\n",
bb->index);
inconsistency_found = true;
}
@@ -4534,7 +4534,7 @@ rebuild_frequencies (void)
return;
}
/* Do not re-propagate if we have profile feedback. Even if the profile is
- inconsistent from previous transofrmations, it is probably more realistic
+ inconsistent from previous transformations, it is probably more realistic
for hot part of the program than result of repropagating.
Consider example where we previously has
@@ -4549,7 +4549,7 @@ rebuild_frequencies (void)
important copy is not the one we look on.
Propagating from probabilities would make profile look consistent, but
- because probablities after code duplication may not be representative
+ because probabilities after code duplication may not be representative
for a given run, we would only propagate the error further. */
if (feedback_found && !uninitialized_count_found)
{
@@ -4626,7 +4626,7 @@ make_pass_rebuild_frequencies (gcc::context *ctxt)
return new pass_rebuild_frequencies (ctxt);
}
-/* Perform a dry run of the branch prediction pass and report comparsion of
+/* Perform a dry run of the branch prediction pass and report comparison of
the predicted and real profile into the dump file. */
void
@@ -4481,7 +4481,7 @@ rebuild_frequencies (void)
if (bb->count.nonzero_p () && bb->count.quality () >= AFDO)
feedback_found = true;
- /* Uninitialized count may be result of inlining or an omision in an
+ /* Uninitialized count may be result of inlining or an omission in an
optimization pass. */
if (!bb->count.initialized_p ())
diff --git a/gcc/rtl.h b/gcc/rtl.h
index d60587dc5ce..93315cb5802 100644
--- a/gcc/rtl.h
+++ b/gcc/rtl.h
@@ -3146,7 +3146,7 @@ extern bool const_vec_series_p_1 (const_rtx, rtx *, rtx
*);
{ B, B + S, B + 2 * S, B + 3 * S, ... }
- for a nonzero S. Store B and S in *BASE_OUT and *STEP_OUT on sucess. */
+ for a nonzero S. Store B and S in *BASE_OUT and *STEP_OUT on success. */
inline bool
const_vec_series_p (const_rtx x, rtx *base_out, rtx *step_out)
@@ -3164,7 +3164,7 @@ const_vec_series_p (const_rtx x, rtx *base_out, rtx
*step_out)
{ B, B + S, B + 2 * S, B + 3 * S, ... }
where B and S are constant or nonconstant. Store B and S in
*BASE_OUT and *STEP_OUT on sucess. */
inline bool
vec_series_p (const_rtx x, rtx *base_out, rtx *step_out)
@@ -3164,7 +3164,7 @@ const_vec_series_p (const_rtx x, rtx *base_out, rtx
{ B, B + S, B + 2 * S, B + 3 * S, ... }
where B and S are constant or nonconstant. Store B and S in
- *BASE_OUT and *STEP_OUT on sucess. */
+ *BASE_OUT and *STEP_OUT on success. */
inline bool
vec_series_p (const_rtx x, rtx *base_out, rtx *step_out)
--
2.43.0